@@ -24,7 +24,7 @@ __author__ = "Paulin-Dev"
 __copyright__ = "Copyright 2022, MyTUI"
 __credits__ = []
 __license__ = "MIT"
-__version__ = "1.0.8"
+__version__ = "1.0.9"
 __maintainer__ = "Paulin-Dev"
 __email__ = ""
 __status__ = "Development"
@@ -261,16 +261,16 @@ class MyTUI:
         if title:
             bar_length = width() - len(title) - 10
             bonus = 1 if len(title) % 2 != 0 and width() % 2 == 0 or len(title) % 2 == 0 and width() % 2 != 0 else 0
-            print(on_blue(" ") + black_on_gray(b"\xe2\x94\x8c".decode() + f'{HORIZONTAL_BAR*((bar_length//2))}' + b"\xe2\x94\xa4".decode() + '  ') + red_on_gray(title) + black_on_gray("  " + b"\xe2\x94\x9c".decode() + f'{HORIZONTAL_BAR*((bar_length//2)-1+bonus)}' + b"\xe2\x94\x90".decode()) + on_blue("  "))
+            print(on_blue(" ") + black_on_gray(b"\xe2\x94\x8c".decode() + HORIZONTAL_BAR*((bar_length//2)) + b"\xe2\x94\xa4".decode() + '  ') + red_on_gray(title) + black_on_gray("  " + b"\xe2\x94\x9c".decode() + HORIZONTAL_BAR*((bar_length//2)-1+bonus) + b"\xe2\x94\x90".decode()) + on_blue("  "))
         else:
-            print(on_blue(" ") + black_on_gray(b"\xe2\x94\x8c".decode() + f'{HORIZONTAL_BAR*(width()-5)}' + b"\xe2\x94\x90".decode()) + on_blue("  "))
+            print(on_blue(" ") + black_on_gray(b"\xe2\x94\x8c".decode() + HORIZONTAL_BAR*(width()-5) + b"\xe2\x94\x90".decode()) + on_blue("  "))
         print(f'{on_blue(" ") + black_on_gray(VERTICAL_BAR + " "*(width()-5) + VERTICAL_BAR) + on_black(" ") + on_blue(" ")}')
 
     @classmethod
     def __display_bottom(cls, spaces: int, extra_line: bool = True, yesno: bool = False, menu: bool = False, input: bool = False) -> None:
         if extra_line:
             print(f'{on_blue(" ") + black_on_gray(VERTICAL_BAR + " "*(width()-5) + VERTICAL_BAR) + on_black(" ") + on_blue(" ")}')
-        print(on_blue(" ") + black_on_gray(b"\xe2\x94\x94".decode() + f'{HORIZONTAL_BAR*(width()-5)}' + b"\xe2\x94\x98".decode()) + on_black(" ") + on_blue(" "))
+        print(on_blue(" ") + black_on_gray(b"\xe2\x94\x94".decode() + HORIZONTAL_BAR*(width()-5) + b"\xe2\x94\x98".decode()) + on_black(" ") + on_blue(" "))
         print(on_blue("  ") + on_black(" "*(width()-3) + on_blue(" ")))
 
         for i in range(spaces):
